@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2011 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2012 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -64,11 +64,11 @@
 package RT::Action;
 
 use strict;
+use warnings;
 use Scalar::Util;
 
 use base qw/RT::Base/;
 
-# {{{ sub new 
 sub new  {
   my $proto = shift;
   my $class = ref($proto) || $proto;
@@ -77,9 +77,7 @@ sub new  {
   $self->_Init(@_);
   return $self;
 }
-# }}}
 
-# {{{ sub _Init 
 sub _Init  {
   my $self = shift;
   my %args = ( Argument => undef,
@@ -109,102 +107,78 @@ sub _Init  {
   Scalar::Util::weaken($self->{'TransactionObj'});
 
 }
-# }}}
 
 # Access Scripwide data
 
-# {{{ sub Argument 
 sub Argument  {
   my $self = shift;
   return($self->{'Argument'});
 }
-# }}}
 
-# {{{ sub TicketObj
 sub TicketObj  {
   my $self = shift;
   return($self->{'TicketObj'});
 }
-# }}}
 
-# {{{ sub TransactionObj
 sub TransactionObj  {
   my $self = shift;
   return($self->{'TransactionObj'});
 }
-# }}}
 
-# {{{ sub TemplateObj
 sub TemplateObj  {
   my $self = shift;
   return($self->{'TemplateObj'});
 }
-# }}}
 
-# {{{ sub ScripObj
 sub ScripObj  {
   my $self = shift;
   return($self->{'ScripObj'});
 }
-# }}}
 
-# {{{ sub ScripActionObj
 sub ScripActionObj  {
   my $self = shift;
   return($self->{'ScripActionObj'});
 }
-# }}}
 
-# {{{ sub Type
 sub Type  {
   my $self = shift;
   return($self->{'Type'});
 }
-# }}}
 
 
 # Scrip methods
 
 #Do what we need to do and send it out.
 
-# {{{ sub Commit 
 sub Commit  {
   my $self = shift;
   return(0, $self->loc("Commit Stubbed"));
 }
-# }}}
 
 
 #What does this type of Action does
 
-# {{{ sub Describe 
 sub Describe  {
   my $self = shift;
   return $self->loc("No description for [_1]", ref $self);
 }
-# }}}
 
 
 #Parse the templates, get things ready to go.
 
-# {{{ sub Prepare 
 sub Prepare  {
   my $self = shift;
   return (0, $self->loc("Prepare Stubbed"));
 }
-# }}}
 
 
 #If this rule applies to this transaction, return true.
 
-# {{{ sub IsApplicable 
 sub IsApplicable  {
   my $self = shift;
   return(undef);
 }
-# }}}
 
-# {{{ sub DESTROY
 sub DESTROY {
     my $self = shift;
 
@@ -217,7 +191,6 @@ sub DESTROY {
     $self->{'TransactionObj'} = undef;
 }
 
-# }}}
 
 RT::Base->_ImportOverlays();
 
