@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2011 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2012 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -51,6 +51,7 @@ package RT::SQL;
 use strict;
 use warnings;
 
+
 use constant HAS_BOOLEAN_PARSER => do {
     local $@;
     eval { require Parse::BooleanLogic; 1 }
@@ -70,7 +71,7 @@ my $re_aggreg      = qr[(?i:AND|OR)];
 my $re_delim       = qr[$RE{delimited}{-delim=>qq{\'\"}}];
 my $re_value       = qr[[+-]?\d+|NULL|$re_delim];
 my $re_keyword     = qr[[{}\w\.]+|$re_delim];
-my $re_op          = qr[=|!=|>=|<=|>|<|(?i:IS NOT)|(?i:IS)|(?i:NOT LIKE)|(?i:LIKE)]; # long to short
+my $re_op          = qr[=|!=|>=|<=|>|<|(?i:IS NOT)|(?i:IS)|(?i:NOT LIKE)|(?i:LIKE)|(?i:NOT STARTSWITH)|(?i:STARTSWITH)|(?i:NOT ENDSWITH)|(?i:ENDSWITH)]; # long to short
 my $re_open_paren  = qr[\(];
 my $re_close_paren = qr[\)];
 
@@ -92,6 +93,7 @@ sub ParseToArray {
 
 sub Parse {
     my ($string, $cb) = @_;
+    my $loc = sub {HTML::Mason::Commands::loc(@_)};
     $string = '' unless defined $string;
 
     my $want = KEYWORD | OPEN_PAREN;
@@ -128,7 +130,7 @@ sub Parse {
         unless ($current && $want & $current) {
             my $tmp = substr($string, 0, pos($string)- length($match));
             $tmp .= '>'. $match .'<--here'. substr($string, pos($string));
-            my $msg = "Wrong query, expecting a ". _BitmaskToString($want) ." in '$tmp'";
+            my $msg = $loc->("Wrong query, expecting a [_1] in '[_2]'", _BitmaskToString($want), $tmp);
             return $cb->{'Error'}->( $msg ) if $cb->{'Error'};
             die $msg;
         }
@@ -178,7 +180,7 @@ sub Parse {
             $want = AGGREG;
             $want |= CLOSE_PAREN if $depth;
         } else {
-            my $msg = "Query parser is lost";
+            my $msg = $loc->("Query parser is lost");
             return $cb->{'Error'}->( $msg ) if $cb->{'Error'};
             die $msg;
         }
@@ -187,15 +189,15 @@ sub Parse {
     } # while
 
     unless( !$last || $last & (CLOSE_PAREN | VALUE) ) {
-        my $msg = "Incomplete query, last element ("
-            . _BitmaskToString($last)
-            . ") is not CLOSE_PAREN or VALUE in '$string'";
+        my $msg = $loc->("Incomplete query, last element ([_1]) is not close paren or value in '[_2]'",
+                         _BitmaskToString($last),
+                         $string);
         return $cb->{'Error'}->( $msg ) if $cb->{'Error'};
         die $msg;
     }
 
     if( $depth ) {
-        my $msg = "Incomplete query, $depth paren(s) isn't closed in '$string'";
+        my $msg = $loc->("Incomplete query, [quant,_1,unclosed paren] in '[_2]'", $depth, $string);
         return $cb->{'Error'}->( $msg ) if $cb->{'Error'};
         die $msg;
     }
