@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2011 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2012 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -51,11 +51,12 @@ package RT::Shredder::POD;
 use strict;
 use warnings;
 use Pod::Select;
+use Pod::PlainText;
 
 sub plugin_html
 {
     my ($file, $out_fh) = @_;
-    my $parser = new RT::Shredder::POD::HTML;
+    my $parser = RT::Shredder::POD::HTML->new;
     $parser->select('ARGUMENTS', 'USAGE');
     $parser->parse_from_file( $file, $out_fh );
 }
@@ -63,9 +64,8 @@ sub plugin_html
 sub plugin_cli
 {
     my ($file, $out_fh, $no_name) = @_;
-    use Pod::PlainText;
     local @Pod::PlainText::ISA = ('Pod::Select', @Pod::PlainText::ISA);
-    my $parser = new Pod::PlainText;
+    my $parser = Pod::PlainText->new();
     $parser->select('SYNOPSIS', 'ARGUMENTS', 'USAGE');
     $parser->add_selection('NAME') unless $no_name;
     $parser->parse_from_file( $file, $out_fh );
@@ -74,9 +74,8 @@ sub plugin_cli
 sub shredder_cli
 {
     my ($file, $out_fh) = @_;
-    use Pod::PlainText;
     local @Pod::PlainText::ISA = ('Pod::Select', @Pod::PlainText::ISA);
-    my $parser = new Pod::PlainText;
+    my $parser = Pod::PlainText->new();
     $parser->select('NAME', 'SYNOPSIS', 'USAGE', 'OPTIONS');
     $parser->parse_from_file( $file, $out_fh );
 }
